@@ -1,7 +1,13 @@
 /*
- * $Id: sc_vector.c,v 1.4 2004/06/23 12:59:01 jklein Exp $
+ * $Id: sc_vector.c,v 1.6 2004/06/26 06:29:20 jklein Exp $
  * $Author: jklein $
  * $Log: sc_vector.c,v $
+ * Revision 1.6  2004/06/26 06:29:20  jklein
+ * Added sort function and IO utilities.
+ *
+ * Revision 1.5  2004/06/24 15:16:50  jklein
+ * sxarray_t was added for abstruction of collection structure.
+ *
  * Revision 1.4  2004/06/23 12:59:01  jklein
  * Added scale/btree.h, sc_btree.c.
  *
@@ -152,10 +158,56 @@ s_vector_join(svector_t *dst, svector_t *src)
 }
 
 
+static int
+_s_vector_qsort_pivot(spointer list[], int low, int high, sc_compf_t cmpf)
+{
+	int k = low + 1;
+
+	while (k <= high && cmpf(list[low], list[k]) == 0)
+		k++;
+
+	if (k > high)
+		return -1;
+
+	return (cmpf(list[low], list[k]) >= 0)?low:k;
+}
+
+
+static void
+_s_vector_qsort(spointer list[], int low, int high, sc_compf_t cmpf)
+{
+	int p;
+
+	/* done */
+	if (low == high) return;
+
+	if ((p = _s_vector_qsort_pivot(list, low, high, cmpf)) != -1) {
+		spointer x = list[p];
+		int i = low;
+		int j = high;
+
+		while (i <= j) {
+			while (cmpf(list[i], x) < 0) ++i;
+			while (cmpf(list[j], x) > 0) --j;
+
+			/* swap */
+			if (i <= j) {
+				spointer tmp = list[i];
+				list[i] = list[j];
+				list[j] = tmp;
+				i++, j--;
+			}
+		}
+		_s_vector_qsort(list, low, i-1, cmpf);
+		_s_vector_qsort(list, i, high, cmpf);
+	}
+}
+
+
 void
 s_vector_sort(svector_t *vect, sc_compf_t cmpf)
 {
-	// not yet
+	_s_vector_qsort(vect->array, 0, s_vector_size(vect) - 1, cmpf);
 }
 
 
