@@ -1,7 +1,16 @@
 /**
- * $Id: tester.c,v 1.5 2004/06/23 12:59:01 jklein Exp $
+ * $Id: tester.c,v 1.8 2004/06/27 13:35:17 jklein Exp $
  * $Author: jklein $
  * $Log: tester.c,v $
+ * Revision 1.8  2004/06/27 13:35:17  jklein
+ * Added few functions for sbuffer_t and few macros for sxarray_t.
+ *
+ * Revision 1.7  2004/06/26 06:29:20  jklein
+ * Added sort function and IO utilities.
+ *
+ * Revision 1.6  2004/06/24 15:16:50  jklein
+ * sxarray_t was added for abstruction of collection structure.
+ *
  * Revision 1.5  2004/06/23 12:59:01  jklein
  * Added scale/btree.h, sc_btree.c.
  *
@@ -66,21 +75,21 @@ sxarray_tester(sxarray_t *xarr)
 
 	printf("\t - sxarray test");
 
-	xarr->add(xarr, "A");
-	xarr->add(xarr, "B");
-	xarr->add(xarr, "C");
+	s_xarray_add(xarr, "A");
+	s_xarray_add(xarr, "B");
+	s_xarray_add(xarr, "C");
 
-	assert(xarr->size(xarr) == 3);
-	assert(strcmp(xarr->get(xarr, 0), "A") == 0);
-	assert(strcmp(xarr->get(xarr, 1), "B") == 0);
-	assert(strcmp(xarr->get(xarr, 2), "C") == 0);
-	assert(xarr->find(xarr, s_string_compare, "A") == 0);
-	assert(xarr->find(xarr, s_string_compare, "B") == 1);
-	assert(xarr->find(xarr, s_string_compare, "C") == 2);
-	assert(strcmp(xarr->remove(xarr, 0), "A") == 0);
-	assert(strcmp(xarr->remove(xarr, 0), "B") == 0);
-	assert(strcmp(xarr->remove(xarr, 0), "C") == 0);
-	assert(xarr->size(xarr) == 0);
+	assert(s_xarray_size(xarr) == 3);
+	assert(strcmp(s_xarray_get(xarr, 0), "A") == 0);
+	assert(strcmp(s_xarray_get(xarr, 1), "B") == 0);
+	assert(strcmp(s_xarray_get(xarr, 2), "C") == 0);
+	assert(s_xarray_find(xarr, s_string_compare, "A") == 0);
+	assert(s_xarray_find(xarr, s_string_compare, "B") == 1);
+	assert(s_xarray_find(xarr, s_string_compare, "C") == 2);
+	assert(strcmp(s_xarray_remove(xarr, 0), "A") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "B") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "C") == 0);
+	assert(s_xarray_size(xarr) == 0);
 
 	printf("\t[  O  K  ]\n");
 }
@@ -115,25 +124,37 @@ test_list(void)
 	assert(s_list_find(list, s_string_compare, "C") == 1);
 
 	sublist = s_list_alloc();
+	s_list_add(sublist, "F");
 	s_list_add(sublist, "D");
 	s_list_add(sublist, "E");
-	assert(sublist->count == 2);
+	s_list_add(sublist, "Z");
+	s_list_add(sublist, "S");
+
+	s_list_sort(sublist, s_string_compare);
+
+	assert(strcmp(s_list_remove(sublist, 3), "S") == 0);
+	assert(strcmp(s_list_remove(sublist, 3), "Z") == 0);
+
+	assert(sublist->count == 3);
 	assert(s_list_find(sublist, s_string_compare, "D") == 0);
 	assert(s_list_find(sublist, s_string_compare, "E") == 1);
+	assert(s_list_find(sublist, s_string_compare, "F") == 2);
 
 	assert(s_list_join(list, sublist));
 
-	assert(list->count == 4);
+	assert(list->count == 5);
 
 	assert(strcmp(s_list_get(list, 0), "A") == 0);
 	assert(strcmp(s_list_get(list, 1), "C") == 0);
 	assert(strcmp(s_list_get(list, 2), "D") == 0);
 	assert(strcmp(s_list_get(list, 3), "E") == 0);
+	assert(strcmp(s_list_get(list, 4), "F") == 0);
 	
 	assert(s_list_find(list, s_string_compare, "A") == 0);
 	assert(s_list_find(list, s_string_compare, "C") == 1);
 	assert(s_list_find(list, s_string_compare, "D") == 2);
 	assert(s_list_find(list, s_string_compare, "E") == 3);
+	assert(s_list_find(list, s_string_compare, "F") == 4);
 
 	{ /* list iterator test */
 		slist_t *itrlist = s_list_alloc();
@@ -201,9 +222,12 @@ test_vector(void)
 
 
 	subvect = s_vector_alloc();
+	s_vector_add(subvect, "c");
 	s_vector_add(subvect, "a");
 	s_vector_add(subvect, "b");
-	s_vector_add(subvect, "c");
+
+	s_vector_sort(subvect, s_string_compare);
+
 	assert(s_vector_size(subvect) == 3);
 
 	assert(s_vector_join(vect, subvect));
@@ -274,6 +298,12 @@ test_buffer(void)
 	assert(s_buffer_sprintf(sbuf, "NO.%d", 1) == 4);
 	assert(strcmp(sbuf->string, "NO.1") == 0);
 
+	s_buffer_chrrep(sbuf, '1', '2');
+	assert(strcmp(sbuf->string, "NO.2") == 0);
+
+	s_buffer_strrep(sbuf, "NO", "XX");
+	assert(strcmp(sbuf->string, "XX.2") == 0);
+
 	s_buffer_free(sbuf);
 	FUNC_END();
 	return 1;
